@@ -1,15 +1,16 @@
-﻿"""说明 Instructions:
+"""说明 Instructions:
 A simple text editor written in Python.It supports editing text files,
 binary files ,encodings and changing font size.
 When you edit a binary file, the contents of the file are
 displayed as escape sequences.
 And code highlighting is supported when editing Python code files,like IDLE.
 
-一款使用Python编写的文本编辑器, 支持编辑文本文件、二进制文件、改变字体大小。
+一款使用tkinter编写的文本编辑器, 支持编辑文本文件、二进制文件、改变字体大小。
 支持ansi、gbk和utf-8编码。编辑二进制文件时, 文件内容以转义序列形式显示。
-编辑python代码文件时, 也支持代码高亮显示, 类似IDLE。
+编辑python代码文件时, 支持代码高亮显示, 类似IDLE。
 
 作者:qfcy (七分诚意)
+版本:1.2.5
 """
 import sys,os,time
 from tkinter import *
@@ -25,24 +26,36 @@ except ImportError:
     ColorDelegator=Percolator=None
 
 
-__all__=["directories","search"]
 __email__="3416445406@qq.com"
 __author__="七分诚意 qq:3076711200 邮箱:%s"%__email__
-__version__="1.0.2"
+__version__="1.2.5"
 
 #_REPLACE_CHARS=['\x00','\r']
-def bytes_to_charmap(bytes):
+def view_hex(bytes):
     result=''
-    for char in bytes:
-        if char>32 and char<127:
-            result+=chr(char)
-        else:result+=str(char)+' '
+    for i in range(0,len(bytes)):
+        result+= hex(bytes[i])[2:] + ' '
+        if (i+1) % 4 == 0:result+='\n'
     return result
-def _is_pythonfile(filename):
-    python_ext=".py",".pyc",".pyw" #ext:文件扩展名
-    for ext in python_ext:
-        if filename.endswith(ext):return True
-    return False
+
+def to_escape_str(bytes):
+    # 将字节(bytes)转换为转义字符串
+    str='';length=1024
+    for i in range(0,len(bytes),length):
+        str+=repr( bytes[i: i+length] ) [2:-1]
+        str+='\n'
+    return str
+
+def to_bytes(escape_str):
+    # 将转义字符串转换为字节
+    # -*****- 1.2.5版更新: 忽略二进制模式中文字的换行符
+    escape_str=escape_str.replace('\n','')
+    escape_str=escape_str.replace('"""','\\"""')
+    escape_str=escape_str.replace("'''","\\'''")
+    try:
+        return eval('b"""'+escape_str+'"""')
+    except SyntaxError:
+        return eval("b'''"+escape_str+"'''")
 
 class SearchDialog(Toplevel):
     #查找对话框
@@ -89,13 +102,13 @@ class SearchDialog(Toplevel):
         self.use_escape_char.set(self.master.isbinary)
         ttk.Checkbutton(master,text="转义字符",variable=self.use_escape_char)\
         .pack(side=LEFT)
-    
+
     def search(self,event=None,mark=True,bell=True):
         text=self.master.contents
         key=self.keyword.get()
         if not key:return
         if self.use_escape_char.get():
-            key=repr(bytes(eval("'%s'"%key),encoding=self.coding))[2:-1]
+            key=str(to_bytes(key),encoding=self.coding)
         text.tag_remove("sel","1.0",END)
         pos=text.search(key,INSERT,END,
                         regexp=self.use_regexpr.get(),
@@ -105,10 +118,19 @@ class SearchDialog(Toplevel):
             text.mark_set(INSERT,newpos)
             if mark:self.mark_text(pos,newpos)
             return pos,newpos
-        elif bell:self.bell()
+        elif bell: # 未找到
+            try: # -*****- 1.2.5版更新
+                import winsound
+                winsound.PlaySound('.',winsound.SND_ASYNC)
+            except (ImportError, RuntimeError):
+                self.bell()
     def mark_text(self,start_pos,end_pos):
         text=self.master.contents
-        text.tag_add("sel",start_pos,end_pos)
+        #text.tag_config("found",background="#8888ff")
+        text.tag_add("sel", start_pos,end_pos)
+        lines=text.get('1.0',END)[:-1].count(os.linesep) + 1
+        lineno=int(start_pos.split('.')[0])
+        text.yview('moveto', str((lineno-text['height'])/lines)) # -****- 1.2.5版
         text.focus_force()
         self.master.update_status()
     def onquit(self,event):
@@ -126,7 +148,7 @@ class ReplaceDialog(SearchDialog):
         ttk.Button(frame,text="全部替换",command=self.replace_all).pack()
         ttk.Button(frame,text="退出",command=self.destroy).pack()
         frame.pack(side=RIGHT,fill=Y)
-        
+
         inputbox=Frame(self)
         Label(inputbox,text="查找内容:").pack(side=LEFT)
         self.keyword=StringVar()
@@ -134,7 +156,7 @@ class ReplaceDialog(SearchDialog):
         keyword.pack(side=LEFT,expand=True,fill=X)
         keyword.focus_force()
         inputbox.pack(fill=X)
-        
+
         replace=Frame(self)
         Label(replace,text="替换为:  ").pack(side=LEFT)
         self.text_to_replace=StringVar()
@@ -142,7 +164,7 @@ class ReplaceDialog(SearchDialog):
         replace_text.pack(side=LEFT,expand=True,fill=X)
         replace_text.bind("<Key-Return>",self.replace)
         replace.pack(fill=X)
-        
+
         options=Frame(self)
         self.create_options(options)
         options.pack(fill=X)
@@ -152,14 +174,13 @@ class ReplaceDialog(SearchDialog):
         if not result:return -1 #-1标志已无文本可替换
         pos,newpos=result
         newtext=self.text_to_replace.get()
-        if self.use_escape_char.get():
-            newtext=repr(bytes(eval("'%s'"%newtext),encoding=self.coding))[2:-1]
         text.delete(pos,newpos)
         text.insert(pos,newtext)
         end_pos="%s+%dc"%(pos,len(newtext))
         self.mark_text(pos,end_pos)
-        
+
     def replace_all(self):
+        self.master.contents.mark_set("insert","1.0")
         while self.replace(bell=False)!=-1:pass
      
 class Editor(Tk):
@@ -170,6 +191,7 @@ class Editor(Tk):
     FONTSIZES=8, 9, 10, 11, 12, 14, 18, 20, 22, 24, 30
     NORMAL_FONT='宋体'
     NORMAL_FONTSIZE=11
+    FILETYPES=[("所有文件","*.*")]
     windows=[]
     def __init__(self,filename=""):
         super().__init__()
@@ -178,18 +200,21 @@ class Editor(Tk):
         self.bind("<FocusIn>",self.focus)
         self.bind("<FocusOut>",self.focus)
         self.protocol("WM_DELETE_WINDOW",self.ask_for_save)
+
         self.isbinary=self.file_changed=False
         self.bin_data=self.charmap=None
-        self.colorobj=None
-        
+        self.colorobj=self._codefilter=None
+        self.coding=StringVar()
+        self.coding.set(self.NORMAL_CODING)
+        Editor.windows.append(self)
+
         self.load_icon()
         self.create_widgets()
         self.update()
         self.filename=''
-        Editor.windows.append(self)
         if filename:
-            self.filenamebox.insert(END,filename)
-            self.load()
+            #self.filenamebox.insert(END,filename)
+            self.load(filename)
     def load_icon(self):
         for path in sys.path:
             try:
@@ -202,53 +227,35 @@ class Editor(Tk):
         self.statusbar.pack(side=BOTTOM,fill=X)
         self.status=Label(self.statusbar,justify=RIGHT)
         self.status.pack(side=RIGHT)
-        
+
         frame=Frame(self)
         frame.pack(side=TOP,fill=X)
-        self.filenames=[]
-        self.filenamebox = ttk.Combobox(frame)
-        self.filenamebox["value"]=list(reversed(self.filenames))
-        self.filenamebox.pack(side=LEFT, expand=True, fill=X)
-        self.filenamebox.bind("<Key>",self.filenamebox_onkey)
-        self.filenamebox.focus_force()
-        
+
         ttk.Button(frame,text='新建', command=self.new,width=7).pack(side=LEFT)
-        ttk.Button(frame,text='打开', command=self.load,width=7).pack(side=LEFT)
+        ttk.Button(frame,text='打开', command=self.open,width=7).pack(side=LEFT)
+        ttk.Button(frame,text='打开二进制文件',
+                   command=self.open_as_binary,width=13).pack(side=LEFT)
         ttk.Button(frame,text='保存', command=self.save,width=7).pack(side=LEFT)
-        self.run_btn=ttk.Button(frame,width=0,state=DISABLED,command=self.run)
-        self.run_btn.pack(side=LEFT)
-        
-        self.options=Frame(self)
-        self.options.pack(side=TOP,fill=X)
-        self.create_options(self.options)
-        
+
+        Label(frame,text="编码:").pack(side=LEFT)
+        coding=ttk.Combobox(frame,textvariable=self.coding)
+        coding["value"]=self.encodings
+        coding.pack(side=LEFT)
+
         self.contents=ScrolledText(self,undo=True,width=75,height=24,
                                    font=(self.NORMAL_FONT,self.NORMAL_FONTSIZE,"normal"))
         self.contents.pack(expand=True,fill=BOTH)
         self.contents.bind("<Key>",self.text_change)
         self.contents.bind("<B1-ButtonRelease>",self.update_status)
         self.update_offset()
-        
+
         self.create_menu()
-    def create_options(self,master):
-        self.is_binmode=IntVar()
-        ttk.Radiobutton(master,text="文本模式",
-                    variable=self.is_binmode,value=0).pack(side=LEFT)
-        ttk.Radiobutton(master,text="二进制模式",
-                    variable=self.is_binmode,value=1).pack(side=LEFT)
-        
-        Label(master,text="编码:").pack(side=LEFT)
-        self.coding=StringVar()
-        self.coding.set(self.NORMAL_CODING)
-        coding=ttk.Combobox(master,textvariable=self.coding)
-        coding["value"]=self.encodings
-        coding.pack(side=LEFT)
     def create_binarytools(self):
         if self.isbinary:
             if not self.bin_data:
-                self.bin_data=ScrolledText(self.statusbar,width=8,height=6)
+                self.bin_data=ScrolledText(self.statusbar,width=6,height=6)
             if not self.charmap:
-                self.charmap=ScrolledText(self.statusbar,width=20,height=5)
+                self.charmap=ScrolledText(self.statusbar,width=14,height=5)
             self.bin_data.pack(side=LEFT,expand=True,fill=BOTH)
             self.charmap.pack(fill=Y)
             self.status.pack_forget()
@@ -260,55 +267,70 @@ class Editor(Tk):
                 self.charmap.pack_forget()
             self.status.pack(side=RIGHT)
     def create_menu(self):
-        self.basemenu=self._new_menu(self.filenamebox)
-        self.basemenu.add_separator()
-        self.basemenu.add_command(label="浏览 ...",command=self.browse_file)
-        
-        self.editmenu=self._new_menu(self.contents)
+        menu=Menu(self)
+        filemenu=Menu(self,tearoff=False)
+        filemenu.add_command(label="新建",
+                             command=self.new,accelerator="Ctrl+N")
+        filemenu.add_command(label="打开",
+                             command=self.open,accelerator="Ctrl+O")
+        filemenu.add_command(label="打开二进制文件",
+                             command=self.open_as_binary)
+        filemenu.add_command(label="保存",
+                             command=self.save,accelerator="Ctrl+S")
+        filemenu.add_command(label="另存为",command=self.save_as)
+        filemenu.add_separator()
+        filemenu.add_command(label="退出",command=self.ask_for_save)
+
+        self.editmenu=Menu(self.contents,tearoff=False)
+        master=self.contents
+        self.editmenu.add_command(label="剪切  ",
+                         command=lambda:self.text_change()==master.event_generate("<<Cut>>"))
+        self.editmenu.add_command(label="复制  ",
+                         command=lambda:master.event_generate("<<Copy>>"))
+        self.editmenu.add_command(label="粘贴  ",
+                         command=lambda:self.text_change()==master.event_generate("<<Paste>>"))
         self.editmenu.add_separator()
         self.editmenu.add_command(label="查找",accelerator="Ctrl+F",
                                   command=lambda:self.show_dialog(SearchDialog))
         self.editmenu.add_command(label="替换",
                                   command=lambda:self.show_dialog(ReplaceDialog))
         self.editmenu.add_separator()
-        
+
         fontsize=Menu(self.contents,tearoff=False)
         fontsize.add_command(label="增大字体   ",accelerator='Ctrl+ "+"',
                              command=self.increase_font)
         fontsize.add_command(label="减小字体   ",accelerator='Ctrl+ "-"',
                              command=self.decrease_font)
         fontsize.add_separator()
-        
+
         for i in range(len(self.FONTSIZES)):
             def resize(index=i):
                 self.set_fontsize(index)
             fontsize.add_command(label=self.FONTSIZES[i],command=resize)
-        
+
         self.editmenu.add_cascade(label="字体",menu=fontsize)
-        
-    def _new_menu(self,master,tearoff=False,**options):
-        menu=Menu(master,tearoff=tearoff,**options)
-        menu.add_command(label="剪切  ",accelerator="Ctrl+X",
-                         command=lambda:self.text_change()==master.event_generate("<<Cut>>"))
-        menu.add_command(label="复制  ",accelerator="Ctrl+C",
-                         command=lambda:master.event_generate("<<Copy>>"))
-        menu.add_command(label="粘贴  ",accelerator="Ctrl+V",
-                         command=lambda:self.text_change()==master.event_generate("<<Paste>>"))
-        master.bind("<Button-3>",
-                    lambda event:menu.post(event.x_root,event.y_root))
-        return menu
-    def browse_file(self):
-        filename=dialog.askopenfilename(master=self)
-        self.filenamebox.delete(0,END)
-        self.filenamebox.insert(0,filename)
+        self.contents.bind("<Button-3>",
+                    lambda event:self.editmenu.post(event.x_root,event.y_root))
+
+
+        helpmenu=Menu(self,tearoff=False)
+        helpmenu.add_command(label="关于",command=self.about)
+
+        menu.add_cascade(label="文件",menu=filemenu)
+        menu.add_cascade(label="编辑",menu=self.editmenu)
+        menu.add_cascade(label="帮助",menu=helpmenu)
+        # 显示菜单
+        self.config(menu=menu)
+
+
     def show_dialog(self,dialog_type):
-        # dialog_type is the class of the dialog
+        # dialog_type是对话框的类型
         for window in dialog_type.instances:
             if window.master is self:
                 window.focus_force()
                 return
         dialog_type(self).show()
-    
+
     def set_fontsize(self,index):
         newsize=self.FONTSIZES[index]
         self.contents["font"]=(self.NORMAL_FONT,newsize,"normal")
@@ -323,28 +345,26 @@ class Editor(Tk):
         index=self.FONTSIZES.index(fontsize)-1
         if 0<=index<len(self.FONTSIZES): self.set_fontsize(index)
 
-    
-    def filenamebox_onkey(self,event):
-        if event.char=='\r':self.load()
+
     def window_onkey(self,event):
         if event.state==4:#如果按下Ctrl键
             if event.keysym=='o':#按下Ctrl+O键
-                self.load()
+                self.open()
             elif event.keysym=='s':#Ctrl+S键
                 self.save()
             elif event.keysym=='z':#Ctrl+Z
                 try:self.contents.edit_undo()
                 except TclError:self.bell()
                 self.text_change()
-            elif event.keysym=='y':#Ctrl+Y
+            elif event.keysym=='y':
                 try:self.contents.edit_redo()
                 except TclError:self.bell()
                 self.text_change()
-            elif event.keysym=='f':#Ctrl+F
+            elif event.keysym=='f':
                 self.show_dialog(SearchDialog)
-            elif event.keysym=='equal':#Ctrl+ "+"
+            elif event.keysym=='equal':#Ctrl+ "+" 增大字体
                 self.increase_font()
-            elif event.keysym=='minus':#Ctrl+ "-"
+            elif event.keysym=='minus':#Ctrl+ "-" 减小字体
                 self.decrease_font()
     def focus(self,event):
         #当窗口获得或失去焦点时,调用此函数
@@ -354,7 +374,9 @@ class Editor(Tk):
                     if window.wm_state()=="iconic":
                         window.attributes("-toolwindow",True)
                     window.attributes("-topmost",True)
-                    window.deiconify()
+                    if not window.wm_state()=="normal":
+                        window.deiconify()
+                    self.contents.focus_force()
                 else:
                     window.attributes("-topmost",False)
                     if self.wm_state()=="iconic":
@@ -369,13 +391,16 @@ class Editor(Tk):
         if self.isbinary:
             try:
                 selected=self.contents.get(SEL_FIRST,SEL_LAST)
-                data=eval("b'''"+selected+"'''")
-                text=str(data,encoding=self.coding.get(),
-                         errors="backslashreplace")
+                data=to_bytes(selected)
+                try:
+                    text=str(data,encoding=self.coding.get(),
+                             errors="backslashreplace")
+                except TypeError:
+                    text=''
                 self.bin_data.delete("1.0",END)
                 self.bin_data.insert(INSERT,text)
                 self.charmap.delete("1.0",END)
-                self.charmap.insert(INSERT,bytes_to_charmap(data))
+                self.charmap.insert(INSERT,view_hex(data))
                 self.status["text"]="选区长度: %d (Bytes)"%len(data)
             except (TclError,SyntaxError): #未选取内容
                 self.update_offset()
@@ -384,11 +409,11 @@ class Editor(Tk):
         if self.isbinary:
             selected=self.contents.get("1.0",INSERT)
             try:
-                data=eval("b'''"+selected+"'''")
+                data=to_bytes(selected)
             except SyntaxError:
                 sep='\\'
                 selected=sep.join(selected.split(sep)[0:-1])
-                data=eval("b'''"+selected+"'''")
+                data=to_bytes(selected)
             self.status["text"]="偏移量: {} ({})".format(len(data),hex(len(data)))
         else:
             offset=self.contents.index(CURRENT).split('.')
@@ -398,15 +423,28 @@ class Editor(Tk):
     def new(cls):
         window=cls()
         window.focus_force()
-    def load(self):
+    def open(self):
         #加载一个文件
-        filename=self.filenamebox.get()
-        if not filename.strip():return
+        if self.ask_for_save(quit=False)==0:return
+        filename=dialog.askopenfilename(master=self,title='打开',
+                                        filetypes=self.FILETYPES)
+        self.load(filename)
+    def open_as_binary(self):
+        filename=dialog.askopenfilename(master=self,title='打开二进制文件',
+                                        filetypes=self.FILETYPES)
+        self.load(filename,binary=True)
+    def load(self,filename,binary=False):
+        # 加载文件(主要部分)
+        if not filename.strip():
+            return
+        self.isbinary=binary
         if os.path.isfile(filename):
             self.filename=filename
             data=self._load_data(filename)
-            if len(data)>100000:self.title(
+            if len(data)>10000:
+                self.title(
                 "%s - 加载中,请耐心等待..." % self.TITLE)
+                self.update()
             self.contents.delete('1.0', END)
             if self.isbinary:
                 self.contents.insert(INSERT,data)
@@ -419,35 +457,28 @@ class Editor(Tk):
             self.create_binarytools()
             self.change_title()
             self.change_mode()
-            self.filenames.append(filename)
-            self.filenamebox["value"]=list(reversed(self.filenames))
+            self.contents.edit_reset() # -*****- 1.2.5版更新 !!!!!!!!!!!!!!!!
             self.contents.focus_force()
         else:msgbox.showinfo("Error","文件未找到:"+repr(filename))
     def _load_data(self,filename):
         f=open(filename,"rb")#打开文件
-        if self.is_binmode.get():
-            self.isbinary=True
-            return repr(f.read())[2:-1]
-        try:
-            #读取文件,并对文件内容进行编码
-            data=str(f.read(),encoding=self.coding.get())
-            self.isbinary=False
-        except UnicodeDecodeError:
-            f.seek(0)
-            result=msgbox.askyesno("","""%s编码无法解码此文件,
+        if self.isbinary:
+            data=to_escape_str(f.read())
+            return data
+        else:
+            try:
+                #读取文件,并对文件内容进行编码
+                data=str(f.read(),encoding=self.coding.get())
+            except UnicodeDecodeError:
+                f.seek(0)
+                result=msgbox.askyesno("","""%s编码无法解码此文件,
 是否使用二进制模式打开?"""%self.coding.get())
-            if result:
-                self.isbinary=True
-                data=repr(f.read())[2:-1]
-                
-                #data=str(f.read(),encoding=self.coding.get(),
-                #         errors="backslashreplace")
-                #for char in _REPLACE_CHARS:
-                #    print(repr(char)[1:-1])
-                #    data.replace(char,repr(char)[1:-1])
-            else:
-                self.isbinary=False
-                data=str(f.read(),encoding=self.coding.get(),errors="replace")
+                if result:
+                    self.isbinary=True
+                    data=to_escape_str(f.read())
+                else:
+                    self.isbinary=False
+                    data=str(f.read(),encoding=self.coding.get(),errors="replace")
         return data
     def change_title(self,running=False):
         newtitle="PyNotepad - "+os.path.split(self.filename)[1]+\
@@ -455,40 +486,46 @@ class Editor(Tk):
                   (" (运行)" if running else '')
         self.title(newtitle)
     def change_mode(self):
-        if  _is_pythonfile(self.filename):
-            self.run_btn["state"]=NORMAL
-            self.run_btn["text"]='运行程序' 
-        else:
-            self.contents.tag_delete("all")
-            self.run_btn["state"]=DISABLED
-            self.run_btn["text"]=''
         if ColorDelegator:
-            if ( self.filename.endswith(".py") or self.filename.endswith(".pyw"))\
-               and (not self.isbinary):
+            if self.filename.lower().endswith((".py",".pyw"))\
+                   and (not self.isbinary):
                 self._codefilter=ColorDelegator()
                 if not self.colorobj:
                     self.colorobj=Percolator(self.contents)
                 self.colorobj.insertfilter(self._codefilter)
-            elif self.colorobj and self._codefilter:
+            elif self.colorobj and self._codefilter.delegate:
                 self.colorobj.removefilter(self._codefilter)
     def ask_for_save(self,quit=True):
-        if self.file_changed and self.filenamebox.get():
+        my_ret=None
+        if self.file_changed: ## and self.filenamebox.get():
             retval=msgbox.askyesnocancel("文件尚未保存",
                               "是否保存{}的更改?".format(
                                   os.path.split(self.filename)[1] or "当前文件"))
             if not retval is None:
-                if retval==True:self.save()
-            else:return 0  #0:cancel
+                if retval==True:
+                    # 是
+                    ret=self.save()
+                    # 在保存对话框中取消
+                    if ret==0:
+                        my_ret=0;quit=False
+                # 否
+            else:
+                # 取消
+                my_ret=0;quit=False  # 0表示cancel
         if quit:
             Editor.windows.remove(self)
             self.destroy()
+        return my_ret
     def save(self):
         #保存文件
-        filename=self.filenamebox.get()
+        if not self.filename:
+            self.filename=dialog.asksaveasfilename(master=self.master,
+                    filetypes=self.FILETYPES)
+        filename=self.filename
         if filename.strip():
-            text=self.contents.get('1.0', END)[:-1]
+            text=self.contents.get('1.0', END)[:-1] # [:-1]: 去除换行符
             if self.isbinary:
-                data=eval('b"""'+text+'"""')
+                data=to_bytes(text)
             else:data=bytes(text,encoding=self.coding.get())
             file=open(filename, 'wb')
             file.write(data)
@@ -497,43 +534,23 @@ class Editor(Tk):
             self.file_changed=False
             self.change_title()
             self.change_mode()
-            if filename not in self.filenames:
-                self.filenames.append(filename)
-                self.filenamebox["value"]=list(reversed(self.filenames))
-    def run(self):
-        import _thread
-        try:
-            import console
-            c=console.Console()
-            c.colorize()
-        except:pass
-        def _run():
-            self.change_title(running=True)
-            start=time.perf_counter()
-            try:
-                if os.path.isfile(os.getenv("systemroot")+"\py.exe"):
-                    returnval=os.system("py %s" % self.filename)
-                else:returnval=os.system("python %s" % self.filename)
+        else:
+            return 0 # 0表示cancel
+    def save_as(self):
+        self.filename=dialog.asksaveasfilename(master=self.master,
+                    filetypes=self.FILETYPES)
+        self.save()
 
-                print("END with return value {}(用时:{:.6f}秒)".format(
-                    returnval,time.perf_counter()-start),file=sys.stderr)
-            except KeyboardInterrupt:print("STOPPED!",file=sys.stderr)
-            self.change_title(running=False)
-        filename=getattr(self,"filename",'')
-        if filename:
-            print("START:"+filename)
-            _thread.start_new_thread(_run,())
+    def about(self):
+        msgbox.showinfo("关于",__doc__+"\n作者: "+__author__)
 
 def main():
-    def _mainloop():
-        try:mainloop()
-        except KeyboardInterrupt:_mainloop()
     if len(sys.argv)>1:
         for arg in sys.argv[1:]:
             try:
                 Editor(arg)
             except OSError:pass
     else: Editor()
-    _mainloop()
+    mainloop()
 
-if __name__=="__main__":main()
\ No newline at end of file
+if __name__=="__main__":main()
